[hide private]
[frames] | no frames]

[ Module Hierarchy | Class Hierarchy ]

# Class Hierarchy

- exceptions.Exception: Common base class for all exceptions.
  - mysql.exceptions.base.Error: Base class for all MySQL exceptions.
    - mysql.exceptions.internal.Result_Unbuffered_Error: Attempted to call a method that requires the results to be buffered (stored) locally.
    - mysql.exceptions.internal.No_Statement_Info_Error: Information is not available for the last statement when using the mysql.connection.Connection.last_statement_info method.
    - mysql.exceptions.internal.Result_Closed_Error: Attempted to use a result object that has been closed.
    - mysql.exceptions.internal.No_More_Rows: The last row was reached in the mysql.result.Result.fetch_row method.
    - mysql.exceptions.base.MySQL_Error: Base class for all MySQL exceptions that have an error code.
      - mysql.exceptions.server.Sp_Varcond_After_Curshndlr: Variable or condition declaration after cursor or handler declaration
      - mysql.exceptions.client.No_Prepare_Stmt: Statement not prepared.
      - mysql.exceptions.server.Cant_Create_Geometry_Object: Cannot get geometry object from data you send to the GEOMETRY field
      - mysql.exceptions.server.Requires_Primary_Key: This table type requires a primary key
      - mysql.exceptions.server.Crashed_On_Repair: Table '%s' is marked as crashed and last (automatic?) repair failed
      - mysql.exceptions.server.Cant_Lock: Can't lock file (errno: %d)
      - mysql.exceptions.server.Server_Shutdown: Server shutdown in progress
      - mysql.exceptions.server.Warn_Too_Few_Records: Row %ld doesn't contain data for all columns
      - mysql.exceptions.client.Shared_Memory_Connect_Map_Error: Can't open shared memory; server could not get pointer to file mapping.
      - mysql.exceptions.client.Connection_Error: Failed to connect to the local MySQL server.
      - mysql.exceptions.client.Conn_Host_Error: Failed to connect to the MySQL server.
      - mysql.exceptions.server.Cant_Create_File: Can't create file '%s' (errno: %d)
      - mysql.exceptions.server.Removed_Spaces: Leading spaces are removed from name '%s'
      - mysql.exceptions.server.No_Default: Variable '%s' doesn't have a default value
      - mysql.exceptions.server.Fparser_Bad_Header: Malformed file type header in file '%s'
      - mysql.exceptions.client.Server_Lost: If connect_timeout > 0 and it took longer than connect_timeout seconds to connect to the server or if the server died while executing the init-command.
      - mysql.exceptions.server.Wrong_Paramcount_To_Procedure: Incorrect parameter count to procedure '%s'
      - mysql.exceptions.server.Bad_Slave: The server is not configured as slave; fix in config file or with CHANGE MASTER TO
      - mysql.exceptions.client.No_Parameters_Exists: No parameters exist in the statement.
      - mysql.exceptions.server.Cant_Create_Federated_Table: Can't create federated table.
      - mysql.exceptions.server.Cant_Get_Wd: Can't get working directory (errno: %d)
      - mysql.exceptions.server.Global_Variable: Variable '%s' is a GLOBAL variable and should be set with SET GLOBAL
      - mysql.exceptions.server.Too_Big_For_Uncompress: Uncompressed data size too large; the maximum size is %d (probably, length of uncompressed data was corrupted)
      - mysql.exceptions.server.Table_Cant_Handle_Ft: The used table type doesn't support FULLTEXT indexes
      - mysql.exceptions.server.Too_Many_Fields: Too many columns
      - mysql.exceptions.server.No_Such_User: There is no '%s'@'%s' registered
      - mysql.exceptions.server.Update_Table_Used: You can't specify target table '%s' for update in FROM clause
      - mysql.exceptions.server.Cant_Get_Stat: Can't get status of '%s' (errno: %d)
      - mysql.exceptions.client.Server_Handshake_Err: Error in server handshake.
      - mysql.exceptions.server.Wrong_Auto_Key: Incorrect table definition; there can be only one auto column and it must be defined as a key
      - mysql.exceptions.server.Get_Temporary_Errmsg: Got temporary error %d '%s' from %s
      - mysql.exceptions.server.Flush_Master_Binlog_Closed: Binlog closed, cannot RESET MASTER
      - mysql.exceptions.server.Revoke_Grants: Can't revoke all privileges, grant for one or more of the requested users
      - mysql.exceptions.server.Cant_Aggregate_Ncollations: Illegal mix of collations for operation '%s'
      - mysql.exceptions.server.Cant_Find_Udf: Can't load function '%s'
      - mysql.exceptions.client.Server_Gone_Error: MySQL server has gone away.
      - mysql.exceptions.server.Cant_Reopen_Table: Can't reopen table: '%s'
      - mysql.exceptions.server.Sp_Uninit_Var: Referring to uninitialized variable %s
      - mysql.exceptions.server.Cant_Open_Library: Can't open shared library '%s' (errno: %d %s)
      - mysql.exceptions.server.View_No_Explain: EXPLAIN/SHOW can not be issued; lacking privileges for underlying table
      - mysql.exceptions.server.Error_On_Write: Error writing file '%s' (errno: %d)
      - mysql.exceptions.server.Wrong_Field_With_Group: '%s' isn't in GROUP BY
      - mysql.exceptions.server.No_Such_Table: Table '%s.%s' doesn't exist
      - mysql.exceptions.server.Foreign_Data_Source_Doesnt_Exist: The foreign data source you are trying to reference does not exist.
      - mysql.exceptions.server.Net_Read_Error: Got an error reading communication packets
      - mysql.exceptions.server.Get_Errmsg: Got error %d '%s' from %s
      - mysql.exceptions.server.Malformed_Definer: Definer is not fully qualified
      - mysql.exceptions.server.No_Group_For_Proc: Select must have a group with this procedure
      - mysql.exceptions.server.Cant_Use_Option_Here: Incorrect usage/placement of '%s'
      - mysql.exceptions.server.No_Such_Index: Table '%s' has no index like the one used in CREATE INDEX; recreate the table
      - mysql.exceptions.server.Forcing_Close: %s: Forcing close of thread %ld user: '%s'
      - mysql.exceptions.server.Error_During_Flush_Logs: Got error %d during FLUSH_LOGS
      - mysql.exceptions.server.Spatial_Cant_Have_Null: All parts of a SPATIAL index must be NOT NULL
      - mysql.exceptions.server.Udf_No_Paths: No paths allowed for shared library
      - mysql.exceptions.client.Unsupported_Param_Type: The conversion is not supported.
      - mysql.exceptions.server.Function_Not_Defined: Function '%s' is not defined
      - mysql.exceptions.server.Wrong_Outer_Join: Cross dependency found in OUTER JOIN; examine your ON conditions
      - mysql.exceptions.server.Cant_Create_DB: Can't create database '%s' (errno: %d)
      - mysql.exceptions.server.Wrong_Value_For_Var: Variable '%s' can't be set to the value of '%s'
      - mysql.exceptions.client.Invalid_Buffer_Use: Indicates if the bind is to supply the long data in chunks and if the buffer type is non string or binary.
      - mysql.exceptions.server.Table_Not_Locked_For_Write: Table '%s' was locked with a READ lock and can't be updated
      - mysql.exceptions.server.No_File_Mapping: Can't map file: %s, errno: %d
      - mysql.exceptions.server.Net_Uncompress_Error: Couldn't uncompress communication packet
      - mysql.exceptions.client.No_Stmt_Metadata: Prepared statement contains no metadata.
      - mysql.exceptions.server.Unsupported_Extension: Table '%s' uses an extension that doesn't exist in this MySQL version
      - mysql.exceptions.server.Cant_Drop_Field_Or_Key: Can't DROP '%s'; check that column/key exists
      - mysql.exceptions.server.View_Other_User: You need the SUPER privilege for creation view with %s@%s definer
      - mysql.exceptions.server.Wrong_Number_Of_Columns_In_Select: The used SELECT statements have a different number of columns
      - mysql.exceptions.server.View_Wrong_List: View's SELECT and view's field list have different column counts
      - mysql.exceptions.server.Slave_Ignored_Ssl_Params: SSL parameters in CHANGE MASTER are ignored because this MySQL slave was compiled without SSL support; they can be used later if MySQL slave with SSL is started
      - mysql.exceptions.server.No_Default_For_View_Field: Field of view '%s.%s' underlying table doesn't have a default value
      - mysql.exceptions.server.Wrong_Fk_Def: Incorrect foreign key definition for '%s': %s
      - mysql.exceptions.server.Table_Cant_Handle_Blob: The used table type doesn't support BLOB/TEXT columns
      - mysql.exceptions.server.Too_Many_Delayed_Threads: Too many delayed threads in use
      - mysql.exceptions.server.Truncated_Wrong_Value_For_Field: Incorrect %s value: '%s' for column '%s' at row %ld
      - mysql.exceptions.server.Cant_Update_Used_Table_In_Sf_Or_Trg: Can't update table '%s' in stored function/trigger because it is already used by statement which invoked this stored function/trigger.
      - mysql.exceptions.server.Cant_Do_This_During_An_Transaction: You are not allowed to execute this command in a transaction
      - mysql.exceptions.server.Zlib_Z_Buf_Error: ZLIB: Not enough room in the output buffer (probably, length of uncompressed data was corrupted)
      - mysql.exceptions.server.Host_Not_Privileged: Host '%s' is not allowed to connect to this MySQL server
      - mysql.exceptions.server.Fseek_Fail: Failed on fseek()
      - mysql.exceptions.server.Exec_Stmt_With_Open_Cursor: You can't execute a prepared statement which has an open cursor associated with it.
      - mysql.exceptions.server.Wrong_Value_Count_On_Row: Column count doesn't match value count at row %ld
      - mysql.exceptions.server.Cant_Set_Wd: Can't change dir to '%s' (errno: %d)
      - mysql.exceptions.client.No_Result_Set: Attempt to read a row while there is no result set associated with the statement.
      - mysql.exceptions.server.Frm_Unknown_Type: File '%s' has unknown type '%s' in its header
      - mysql.exceptions.server.Sp_Undeclared_Var: Undeclared variable: %s
      - mysql.exceptions.client.Shared_Memory_Map_Error: Can't open shared memory; client could not get pointer to file mapping.
      - mysql.exceptions.server.View_Multiupdate: Can not modify more than one base table through a join view '%s.%s'
      - mysql.exceptions.server.Nonexisting_Proc_Grant: There is no such grant defined for user '%s' on host '%s' on routine '%s'
      - mysql.exceptions.server.Trg_No_Definer: No definer attribute for trigger '%-.64s'.'%-.64s'.
      - mysql.exceptions.server.No_Referenced_Row_2: Cannot add or update a child row: a foreign key constraint fails (%s)
      - mysql.exceptions.server.Conflicting_Declarations: Conflicting declarations: '%s%s' and '%s%s'
      - mysql.exceptions.server.Wrong_Mrg_Table: All tables in the MERGE table are not identically defined
      - mysql.exceptions.server.Sp_No_Retset: Not allowed to return a result set from a %s
      - mysql.exceptions.client.Shared_Memory_File_Map_Error: Can't open shared memory; client could not allocate file mapping.
      - mysql.exceptions.server.Warn_Allowed_Packet_Overflowed: Result of %s() was larger than max_allowed_packet (%ld) - truncated
      - mysql.exceptions.server.Nonexisting_Grant: There is no such grant defined for user '%s' on host '%s'
      - mysql.exceptions.server.Cant_Remove_All_Fields: You can't delete all columns with ALTER TABLE; use DROP TABLE instead
      - mysql.exceptions.server.No_Referenced_Row: Cannot add or update a child row: a foreign key constraint fails
      - mysql.exceptions.server.Udf_Exists: Function '%s' already exists
      - mysql.exceptions.server.Con_Count_Error: Too many connections
      - mysql.exceptions.server.Fparser_Error_In_Parameter: Error while parsing parameter '%s' (line: '%s')
      - mysql.exceptions.server.Wrong_Object: '%s.%s' is not %s
      - mysql.exceptions.server.Zlib_Z_Data_Error: ZLIB: Input data corrupted
      - mysql.exceptions.server.Wrong_Type_For_Var: Incorrect argument type to variable '%s'
      - mysql.exceptions.server.Non_Updatable_Table: The target table %s of the %s is not updatable
      - mysql.exceptions.server.Cant_Read_Dir: Can't read dir of '%s' (errno: %d)
      - mysql.exceptions.server.Sp_Already_Exists: %s %s already exists
      - mysql.exceptions.server.Net_Write_Interrupted: Got timeout writing communication packets
      - mysql.exceptions.client.Shared_Memory_Connection: Connection failure when using shared memory.
      - mysql.exceptions.server.Table_Cant_Handle_Auto_Increment: The used table type doesn't support AUTO_INCREMENT columns
      - mysql.exceptions.server.Truncated_Wrong_Value: Truncated incorrect %s value: '%s'
      - mysql.exceptions.server.Update_Log_Deprecated_Ignored: The update log is deprecated and replaced by the binary log; SET SQL_LOG_UPDATE has been ignored
      - mysql.exceptions.server.Too_Long_String: Result string is longer than 'max_allowed_packet' bytes
      - mysql.exceptions.server.Warning_Not_Complete_Rollback: Some non-transactional changed tables couldn't be rolled back
      - mysql.exceptions.server.Yes: YES
      - mysql.exceptions.client.Commands_Out_Of_Sync: Commands out of sync; you can't run this command now.
      - mysql.exceptions.server.Missing_Skip_Slave: It is recommended to use --skip-slave-start when doing step-by-step replication with START SLAVE UNTIL; otherwise, you will get problems if you get an unexpected slave's mysqld restart
      - mysql.exceptions.client.Shared_Memory_Connect_Set_Error: Can't open shared memory; cannot send request event to server.
      - mysql.exceptions.server.Non_Insertable_Table: The target table %-.100s of the %s is not insertable-into
      - mysql.exceptions.client.Cant_Read_Charset: Unable to read the character set file.
      - mysql.exceptions.server.Host_Is_Blocked: Host '%s' is blocked because of many connection errors; unblock with 'mysqladmin flush-hosts'
      - mysql.exceptions.server.Too_Long_Ident: Identifier name '%s' is too long
      - mysql.exceptions.server.Sp_Subselect_Nyi: Subselect value not supported
      - mysql.exceptions.server.Sp_Bad_Cursor_Select: Cursor SELECT must not have INTO
      - mysql.exceptions.server.View_Select_Derived: View's SELECT contains a subquery in the FROM clause
      - mysql.exceptions.client.Shared_Memory_Connect_Request_Error: Can't open shared memory; client could not create request event.
      - mysql.exceptions.server.Wrong_Field_Spec: Incorrect column specifier for column '%s'
      - mysql.exceptions.server.Non_Grouping_Field_Used: non-grouping field '%-.64s' is used in %-.64s clause
      - mysql.exceptions.server.Trans_Cache_Full: Multi-statement transaction required more than 'max_binlog_cache_size' bytes of storage; increase this mysqld variable and try again
      - mysql.exceptions.server.Too_Big_Set: Too many strings for column %s and SET
      - mysql.exceptions.server.Collation_Charset_Mismatch: COLLATION '%s' is not valid for CHARACTER SET '%s'
      - mysql.exceptions.server.Sp_No_Recursive_Create: Can't create a %s from within another stored routine
      - mysql.exceptions.server.Not_Form_File: Incorrect information in file: '%s'
      - mysql.exceptions.server.No_Raid_Compiled: This version of MySQL is not compiled with RAID support
      - mysql.exceptions.server.Aborting_Connection: Aborted connection %ld to db: '%s' user: '%s' (%s)
      - mysql.exceptions.server.Unknown_Time_Zone: Unknown or incorrect time zone: '%s'
      - mysql.exceptions.server.Unexpected_Eof: Unexpected EOF found when reading file '%s' (errno: %d)
      - mysql.exceptions.server.Warn_Qc_Resize: Query cache failed to set size %lu; new query cache size is %lu
      - mysql.exceptions.client.IP_Sock_Error: Failed to create an IP socket.
      - mysql.exceptions.server.New_Aborting_Connection: Aborted connection %ld to db: '%s' user: '%s' host: '%s' (%s)
      - mysql.exceptions.server.Not_Supported_Auth_Mode: Client does not support authentication protocol requested by server; consider upgrading MySQL client
      - mysql.exceptions.server.No_Unique_Logfile: Can't generate a unique log-filename %s.(1-999)
      - mysql.exceptions.server.Non_Uniq_Error: Column '%s' in %s is ambiguous
      - mysql.exceptions.server.Create_DB_With_Read_Lock: CREATE DATABASE not allowed while thread is holding global read lock
      - mysql.exceptions.server.Check_Not_Implemented: The storage engine for the table doesn't support %s
      - mysql.exceptions.client.No_Data: Attempt to read column without prior row fetch.
      - mysql.exceptions.server.Mix_Of_Group_Func_And_Fields: Mixing of GROUP columns (MIN(),MAX(),COUNT(),...) with no GROUP columns is illegal if there is no GROUP BY clause
      - mysql.exceptions.client.Socket_Create_Error: Failed to create a Unix socket.
      - mysql.exceptions.server.Trg_On_View_Or_Temp_Table: Trigger's '%s' is view or temporary table
      - mysql.exceptions.server.Handshake_Error: Bad handshake
      - mysql.exceptions.client.TCP_Connection: TCP connection error.
      - mysql.exceptions.server.No_Triggers_On_System_Schema: Triggers can not be created on system tables
      - mysql.exceptions.server.Xaer_Rmfail: XAER_RMFAIL: The command cannot be executed when global transaction is in the %s state
      - mysql.exceptions.server.Wrong_Value_For_Type: Incorrect %s value: '%s' for function %s
      - mysql.exceptions.client.Invalid_Conn_Handle: Invalid connection handle.
      - mysql.exceptions.server.Check_No_Such_Table: Can't open table
      - mysql.exceptions.server.Forbid_Schema_Change: Changing schema from '%s' to '%s' is not allowed.
      - mysql.exceptions.server.Sp_Cant_Alter: Failed to ALTER %s %s
      - mysql.exceptions.server.Sp_Cond_Mismatch: Undefined CONDITION: %s
      - mysql.exceptions.server.No_Tables_Used: No tables used
      - mysql.exceptions.server.Invalid_Character_String: Invalid %s character string: '%s'
      - mysql.exceptions.server.Sp_Store_Failed: Failed to CREATE %s %s
      - mysql.exceptions.server.Slave_Was_Not_Running: Slave already has been stopped
      - mysql.exceptions.server.View_Frm_No_User: View %s.%s has not definer information (old table format).
      - mysql.exceptions.server.View_Select_Clause: View's SELECT contains a '%s' clause
      - mysql.exceptions.server.Shutdown_Complete: %s: Shutdown complete
      - mysql.exceptions.server.Connect_To_Master: Error connecting to master: %s
      - mysql.exceptions.server.Sp_Case_Not_Found: Case not found for CASE statement
      - mysql.exceptions.server.Failed_Routine_Break_Binlog: A routine failed and has neither NO SQL nor READS SQL DATA in its declaration and binary logging is enabled; if non-transactional tables were updated, the binary log will miss their changes
      - mysql.exceptions.server.Corrupt_Help_DB: Help database is corrupt or does not exist
      - mysql.exceptions.server.Sp_No_Recursion: Recursive stored routines are not allowed.
      - mysql.exceptions.server.Key_Part_0: Key part '%s' length cannot be 0
      - mysql.exceptions.server.Slave_Thread: Could not create slave thread; check system resources
      - mysql.exceptions.server.Sp_Cant_Set_Autocommit: Not allowed to set autocommit from a stored function or trigger
      - mysql.exceptions.server.Order_With_Proc: Can't use ORDER clause with this procedure
      - mysql.exceptions.server.Unknown_Target_Binlog: Target log not found in binlog index
      - mysql.exceptions.server.Insert_Info: Records: %ld Duplicates: %ld Warnings: %ld
      - mysql.exceptions.server.Warn_Null_To_Notnull: Column set to default value; NULL supplied to NOT NULL column '%s' at row %ld
      - mysql.exceptions.server.Wrong_Name_For_Index: Incorrect index name '%s'
      - mysql.exceptions.server.Bad_Field_Error: Unknown column '%s' in '%s'
      - mysql.exceptions.server.Slave_Not_Running: This operation requires a running slave; configure slave and do START SLAVE
      - mysql.exceptions.server.Fparser_Eof_In_Comment: Unexpected end of file while parsing comment '%s'
      - mysql.exceptions.server.Not_Allowed_Command: The used command is not allowed with this MySQL version
      - mysql.exceptions.server.Option_Prevents_Statement: The MySQL server is running with the %s option so it cannot execute this statement
      - mysql.exceptions.server.Index_Rebuild: Failed rebuilding the index of dumped table '%s'
      - mysql.exceptions.server.Slave_Must_Stop: This operation cannot be performed with a running slave; run STOP SLAVE first
      - mysql.exceptions.server.Syntax_Error: You have an error in your SQL syntax; check the manual that corresponds to your MySQL server version for the right syntax to use
      - mysql.exceptions.server.Normal_Shutdown: %s: Normal shutdown
      - mysql.exceptions.server.Trg_No_Such_Row_In_Trg: There is no %s row in %s trigger
      - mysql.exceptions.server.Xaer_Rmerr: XAER_RMERR: Fatal error occurred in the transaction branch - check your data for consistency
      - mysql.exceptions.server.Commit_Not_Allowed_In_Sf_Or_Trg: Explicit or implicit commit is not allowed in stored function or trigger.
      - mysql.exceptions.server.Operand_Columns: Operand should contain %d column(s)
      - mysql.exceptions.server.Incorrect_Global_Local_Var: Variable '%s' is a %s variable
      - mysql.exceptions.server.Dup_Entry: Duplicate entry '%s' for key %d
      - mysql.exceptions.server.Key_Column_Does_Not_Exits: Key column '%s' doesn't exist in table
      - mysql.exceptions.server.Warn_Invalid_Timestamp: Invalid TIMESTAMP value in column '%s' at row %ld
      - mysql.exceptions.server.Sp_Badstatement: %s is not allowed in stored procedures
      - mysql.exceptions.server.Cant_Initialize_Udf: Can't initialize function '%s'; %s
      - mysql.exceptions.server.Bad_Table_Error: Unknown table '%s'
      - mysql.exceptions.server.View_Invalid: View '%s.%s' references invalid table(s) or column(s) or function(s) or definer/invoker of view lack rights to use them
      - mysql.exceptions.server.Cant_Find_Dl_Entry: Can't find function '%s' in library'
      - mysql.exceptions.server.Nonupdateable_Column: Column '%s' is not updatable
      - mysql.exceptions.server.Var_Cant_Be_Read: Variable '%s' can only be set, not read
      - mysql.exceptions.server.Open_As_Readonly: Table '%s' is read only
      - mysql.exceptions.server.Connect_To_Foreign_Data_Source: Unable to connect to foreign data source - database '%s'!
      - mysql.exceptions.server.Sp_Recursion_Limit: Recursive limit %d (as set by the max_sp_recursion_depth variable) was exceeded for routine %.64s
      - mysql.exceptions.server.Ipsock_Error: Can't create IP socket
      - mysql.exceptions.server.View_Delete_Merge_View: Can not delete from join view '%s.%s'
      - mysql.exceptions.server.View_Recursive: `%-.64s`.``%-.64s`` contains view recursion.
      - mysql.exceptions.server.Sp_Dup_Var: Duplicate variable: %s
      - mysql.exceptions.server.Nonuniq_Table: Not unique table/alias: '%s'
      - mysql.exceptions.server.Hostname: host name?
      - mysql.exceptions.server.Kill_Denied_Error: You are not owner of thread %lu
      - mysql.exceptions.server.Username: user name?
      - mysql.exceptions.server.Old_Keyfile: Old key file for table '%s'; repair it!
      - mysql.exceptions.client.Conn_Unknow_Protocol: Wrong or unknown protocol.
      - mysql.exceptions.server.Sp_No_Drop_Sp: Can't drop or alter a %s from within another stored routine
      - mysql.exceptions.server.Invalid_Default: Invalid default value for '%s'
      - mysql.exceptions.server.Io_Err_Log_Index_Read: I/O error reading log index file
      - mysql.exceptions.server.Sp_Dup_Param: Duplicate parameter: %s
      - mysql.exceptions.client.Data_Truncated: Data truncated.
      - mysql.exceptions.server.User_Limit_Reached: User '%s' has exceeded the '%s' resource (current value: %ld)
      - mysql.exceptions.server.Old_File_Format: '%-.64s' has an old format, you should re-create the '%s' object(s).
      - mysql.exceptions.server.Illegal_Ha: Table storage engine for '%s' doesn't have this option
      - mysql.exceptions.server.Unknown_Table: Unknown table '%s' in %s
      - mysql.exceptions.server.Wrong_Name_For_Catalog: Incorrect catalog name '%s'
      - mysql.exceptions.server.Invalid_Use_Of_Null: Invalid use of NULL value
      - mysql.exceptions.server.Illegal_Value_For_Type: Illegal %s '%s' value found during parsing
      - mysql.exceptions.server.No_Permission_To_Create_User: '%s'@'%s' is not allowed to create new users
      - mysql.exceptions.server.Sp_Dup_Handler: Duplicate handler declared in the same block
      - mysql.exceptions.server.Update_Without_Key_In_Safe_Mode: You are using safe update mode and you tried to update a table without a WHERE that uses a KEY column
      - mysql.exceptions.client.Null_Pointer: Invalid use of null pointer.
      - mysql.exceptions.client.Not_Implemented: This feature is not implemented yet.
      - mysql.exceptions.client.Invalid_Parameter_Number: Invalid parameter number.
      - mysql.exceptions.server.Server_Is_In_Secure_Auth_Mode: Server is running in --secure-auth mode, but '%s'@'%s' has a password in the old format; please change the password to the new format
      - mysql.exceptions.server.Datetime_Function_Overflow: Datetime function: %s field overflow
      - mysql.exceptions.server.Sp_Dup_Curs: Duplicate cursor: %s
      - mysql.exceptions.server.Illegal_Grant_For_Table: Illegal GRANT/REVOKE command; please consult the manual to see which privileges can be used
      - mysql.exceptions.server.Wrong_Value_Count: Column count doesn't match value count
      - mysql.exceptions.server.Warn_Using_Other_Handler: Using storage engine %s for table '%s'
      - mysql.exceptions.server.Password_Not_Allowed: You must have privileges to update tables in the mysql database to be able to change passwords for others
      - mysql.exceptions.server.Error_On_Rename: Error on rename of '%s' to '%s' (errno: %d)
      - mysql.exceptions.server.Null_Column_In_Index: Column '%s' is used with UNIQUE or INDEX but is not defined as NOT NULL
      - mysql.exceptions.server.Dup_Argument: Option '%s' used twice in statement
      - mysql.exceptions.server.Sp_Bad_Cursor_Query: Cursor statement must be a SELECT
      - mysql.exceptions.server.Lock_Table_Full: The total number of locks exceeds the lock table size
      - mysql.exceptions.server.Invalid_On_Update: Invalid ON UPDATE clause for '%s' column
      - mysql.exceptions.server.Set_Constants_Only: You may only use constant expressions with SET
      - mysql.exceptions.server.Sp_Dup_Cond: Duplicate condition: %s
      - mysql.exceptions.server.Password_No_Match: Can't find any matching row in the user table
      - mysql.exceptions.server.Update_Log_Deprecated_Translated: The update log is deprecated and replaced by the binary log; SET SQL_LOG_UPDATE has been translated to SET SQL_LOG_BIN
      - mysql.exceptions.server.Not_Supported_Yet: This version of MySQL doesn't yet support '%s'
      - mysql.exceptions.client.Shared_Memory_Event_Error: Can't open shared memory; client could not create an event.
      - mysql.exceptions.client.Unknown_Host: Failed to find the IP address for the hostname.
      - mysql.exceptions.server.Too_Big_Select: The SELECT would examine more than MAX_JOIN_SIZE rows; check your WHERE and use SET SQL_BIG_SELECTS=1 or SET SQL_MAX_JOIN_SIZE=# if the SELECT is okay
      - mysql.exceptions.server.Invalid_Group_Func_Use: Invalid use of group function
      - mysql.exceptions.server.View_Prevent_Update: The definition of table '%s' prevents operation %s on table '%s'.
      - mysql.exceptions.server.View_Checksum: View text checksum failed
      - mysql.exceptions.server.Dup_Fieldname: Duplicate column name '%s'
      - mysql.exceptions.server.Data_Too_Long: Data too long for column '%s' at row %ld
      - mysql.exceptions.server.Sp_Drop_Failed: Failed to DROP %s %s
      - mysql.exceptions.server.Password_Anonymous_User: You are using MySQL as an anonymous user and anonymous users are not allowed to change passwords
      - mysql.exceptions.client.Net_Packet_Too_Large: Got packet bigger than 'max_allowed_packet' bytes.
      - mysql.exceptions.server.Lock_Deadlock: Deadlock found when trying to get lock; try restarting transaction
      - mysql.exceptions.server.DB_Drop_Rmdir: Error dropping database (can't rmdir '%s', errno: %d)
      - mysql.exceptions.server.Sp_Does_Not_Exist: %s %s does not exist
      - mysql.exceptions.server.Passwd_Length: Password hash should be a %d-digit hexadecimal number
      - mysql.exceptions.server.Update_Info: Rows matched: %ld Changed: %ld Warnings: %ld
      - mysql.exceptions.server.Too_Much_Auto_Timestamp_Cols: Incorrect table definition; there can be only one TIMESTAMP column with CURRENT_TIMESTAMP in DEFAULT or ON UPDATE clause
      - mysql.exceptions.server.Unknown_System_Variable: Unknown system variable '%s'
      - mysql.exceptions.server.Warn_Hostname_Wont_Work: MySQL is started in --skip-name-resolve mode; you must restart it without this switch for this grant to work
      - mysql.exceptions.server.No_Such_Thread: Unknown thread id: %lu
      - mysql.exceptions.client.Localhost_Connection: Localhost via UNIX socket.
      - mysql.exceptions.server.Subquery_No_1_Row: Subquery returns more than 1 row
      - mysql.exceptions.server.Form_Not_Found: View '%s' doesn't exist for '%s'
      - mysql.exceptions.server.Checkread: Record has changed since last read in table '%s'
      - mysql.exceptions.server.Illegal_Reference: Reference '%s' not supported (%s)
      - mysql.exceptions.server.Master_Info: Could not initialize master info structure; more error messages can be found in the MySQL error log
      - mysql.exceptions.server.DB_Drop_Exists: Can't drop database '%s'; database doesn't exist
      - mysql.exceptions.server.Sp_Cursor_Not_Open: Cursor is not open
      - mysql.exceptions.server.Dump_Not_Implemented: The storage engine for the table does not support binary table dump
      - mysql.exceptions.server.Parse_Error: %s near '%s' at line %d
      - mysql.exceptions.server.Until_Cond_Ignored: SQL thread is not to be started so UNTIL options are ignored
      - mysql.exceptions.server.View_Select_Variable: View's SELECT contains a variable or parameter
      - mysql.exceptions.server.Local_Variable: Variable '%s' is a SESSION variable and can't be used with SET GLOBAL
      - mysql.exceptions.server.View_Nonupd_Check: CHECK OPTION on non-updatable view '%s.%s'
      - mysql.exceptions.server.Master_Fatal_Error_Reading_Binlog: Got fatal error %d: '%s' from master when reading data from binary log
      - mysql.exceptions.server.DB_Drop_Delete: Error dropping database (can't delete '%s', errno: %d)
      - mysql.exceptions.server.Trg_In_Wrong_Schema: Trigger in wrong schema
      - mysql.exceptions.server.Wrong_Usage: Incorrect usage of %s and %s
      - mysql.exceptions.server.Wrong_Lock_Of_System_Table: You can't combine write-locking of system '%s.%s' table with other tables
      - mysql.exceptions.server.Xaer_Nota: XAER_NOTA: Unknown XID
      - mysql.exceptions.server.Drop_User: Cannot drop one or more of the requested users
      - mysql.exceptions.client.Params_Not_Bound: No data supplied for parameters in prepared statement.
      - mysql.exceptions.server.Unsupported_Ps: This command is not supported in the prepared statement protocol yet
      - mysql.exceptions.server.Load_Info: Records: %ld Deleted: %ld Skipped: %ld Warnings: %ld
      - mysql.exceptions.server.Sp_Badreturn: RETURN is only allowed in a FUNCTION
      - mysql.exceptions.server.Master: Error from master: '%s'
      - mysql.exceptions.server.Sp_Proc_Table_Corrupt: Failed to load routine %s.
      - mysql.exceptions.server.Drop_DB_With_Read_Lock: DROP DATABASE not allowed while thread is holding global read lock
      - mysql.exceptions.server.Outofmemory: Out of memory; restart server and try again (needed %d bytes)
      - mysql.exceptions.server.Too_Big_Scale: Too big scale %d specified for column '%s'.
      - mysql.exceptions.server.Load_From_Fixed_Size_Rows_To_Var: Can't load value from file with fixed size rows to variable
      - mysql.exceptions.server.Sp_Not_Var_Arg: OUT or INOUT argument %d for routine %s is not a variable
      - mysql.exceptions.server.Unknown_Error: Unknown error
      - mysql.exceptions.server.View_Check_Failed: CHECK OPTION failed '%s.%s'
      - mysql.exceptions.client.Malformed_Packet: Malformed packet.
      - mysql.exceptions.server.DB_Access_Denied_Error: Access denied for user '%s'@'%s' to database '%s'
      - mysql.exceptions.server.Ps_No_Recursion: The prepared statement contains a stored routine call that refers to that same statement.
      - mysql.exceptions.server.Division_By_Zero: Division by 0
      - mysql.exceptions.server.Out_Of_Sortmemory: Out of sort memory; increase server sort buffer size
      - mysql.exceptions.client.Wrong_License: Invalid license when connecting to server.
      - mysql.exceptions.server.Sp_Lilabel_Mismatch: %s with no matching label: %s
      - mysql.exceptions.server.Dup_Key: Can't write; duplicate key in table '%s'
      - mysql.exceptions.server.Autoinc_Read_Failed: Failed to read auto-increment value from storage engine
      - mysql.exceptions.server.Sp_No_Aggregate: AGGREGATE is not supported for stored functions
      - mysql.exceptions.server.Cyclic_Reference: Cyclic reference on subqueries
      - mysql.exceptions.server.Ps_Many_Param: Prepared statement contains too many placeholders
      - mysql.exceptions.server.Disk_Full: Disk full (%s); waiting for someone to free some space...
      - mysql.exceptions.server.Out_Of_Resources: Out of memory; check if mysqld or some other process uses all available memory; if not, you may have to use 'ulimit' to allow mysqld to use more memory or you can add more swap space
      - mysql.exceptions.server.Too_Many_User_Connections: User %s already has more than 'max_user_connections' active connections
      - mysql.exceptions.server.Unknown_Storage_Engine: Unknown table engine '%s'
      - mysql.exceptions.server.Warn_Field_Resolved: Field or reference '%s%s%s%s%s' of SELECT #%d was resolved in SELECT #%d
      - mysql.exceptions.server.Wrong_Magic: Wrong magic in %s
      - mysql.exceptions.server.Key_Ref_Do_Not_Match_Table_Ref: Key reference and table reference don't match
      - mysql.exceptions.server.Foreign_Data_String_Invalid_Cant_Create: Can't create federated table.
      - mysql.exceptions.server.Auto_Convert: Converting column '%s' from %s to %s
      - mysql.exceptions.server.M_Bigger_Than_D: For float(M,D), double(M,D) or decimal(M,D), M must be >= D (column '%s').
      - mysql.exceptions.server.Cut_Value_Group_Concat: %d line(s) were cut by GROUP_CONCAT()
      - mysql.exceptions.server.Nonexisting_Table_Grant: There is no such grant defined for user '%s' on host '%s' on table '%s'
      - mysql.exceptions.server.Procaccess_Denied_Error: %s command denied to user '%s'@'%s' for routine '%s'
      - mysql.exceptions.server.Diff_Groups_Proc: Can't handle procedures with differents groups yet
      - mysql.exceptions.client.Out_Of_Memory: MySQL client ran out of memory.
      - mysql.exceptions.server.Alter_Info: Records: %ld Duplicates: %ld
      - mysql.exceptions.server.Logging_Prohibit_Changing_Of: Binary logging and replication forbid changing the global server %s
      - mysql.exceptions.server.Trg_Does_Not_Exist: Trigger does not exist
      - mysql.exceptions.server.Stmt_Has_No_Open_Cursor: The statement (%lu) has no open cursor.
      - mysql.exceptions.server.Xaer_Inval: XAER_INVAL: Invalid arguments (or unsupported command)
      - mysql.exceptions.server.Proc_Auto_Revoke_Fail: Failed to revoke all privileges to dropped routine
      - mysql.exceptions.server.Derived_Must_Have_Alias: Every derived table must have its own alias
      - mysql.exceptions.server.Error_On_Close: Error on close of '%s' (errno: %d)
      - mysql.exceptions.client.Unknown_Error: An unknown error occurred.
      - mysql.exceptions.server.Sp_Bad_Var_Shadow: Variable '%s' must be quoted with `...`, or renamed
      - mysql.exceptions.client.Named_Pipe_Open_Error: Failed to create a named pipe on Windows.
      - mysql.exceptions.client.Ssl_Connection_Error: SSL connection error.
      - mysql.exceptions.server.Log_Purge_Unknown_Err: Unknown error during log purge
      - mysql.exceptions.server.Binlog_Purge_Fatal_Err: Fatal error during log purge
      - mysql.exceptions.server.Proc_Auto_Grant_Fail: Failed to grant EXECUTE and ALTER ROUTINE privileges
      - mysql.exceptions.server.Key_Not_Found: Can't find record in '%s'
      - mysql.exceptions.server.DB_Create_Exists: Can't create database '%s'; database exists
      - mysql.exceptions.server.Startup: %s: ready for connections.
      - mysql.exceptions.server.Sp_Noreturnend: FUNCTION %s ended without RETURN
      - mysql.exceptions.server.Unknown_Com_Error: Unknown command
      - mysql.exceptions.server.Too_Big_Rowsize: Row size too large.
      - mysql.exceptions.client.Version_Error: A protocol mismatch resulted from attempting to connect to a server with a client library that uses a different protocol version.
      - mysql.exceptions.client.Named_Pipe_Connection: Failed to connect to a named pipe on Windows.
      - mysql.exceptions.server.Specific_Access_Denied_Error: Access denied; you need the %s privilege for this operation
      - mysql.exceptions.server.Log_In_Use: A purgeable log is in use, will not purge
      - mysql.exceptions.server.Hashchk: hashchk
      - mysql.exceptions.server.Empty_Query: Query was empty
      - mysql.exceptions.client.Probe_Slave_Status: Error on SHOW SLAVE STATUS:.
      - mysql.exceptions.server.Delayed_Cant_Change_Lock: Delayed insert thread couldn't get requested lock for table %s
      - mysql.exceptions.server.Cannot_Add_Foreign: Cannot add foreign key constraint
      - mysql.exceptions.server.Sp_Label_Redefine: Redefining label %s
      - mysql.exceptions.server.Too_Long_Key: Specified key was too long; max key length is %d bytes
      - mysql.exceptions.server.Warn_View_Without_Key: View being updated does not have complete key of underlying table in it
      - mysql.exceptions.server.Columnaccess_Denied_Error: %s command denied to user '%s'@'%s' for column '%s' in table '%s'
      - mysql.exceptions.server.Access_Denied_Error: Access denied for user '%s'@'%s' (using password: %s)
      - mysql.exceptions.server.Lock_Wait_Timeout: Lock wait timeout exceeded; try restarting transaction
      - mysql.exceptions.client.Embedded_Connection: Embedded server.
      - mysql.exceptions.server.No_View_User: View definer is not fully qualified
      - mysql.exceptions.server.Too_Many_Tables: Too many tables; MySQL can only use %d tables in a join
      - mysql.exceptions.server.Unknown_Stmt_Handler: Unknown prepared statement handler (%.*s) given to %s
      - mysql.exceptions.server.Warn_Deprecated_Syntax: '%s' is deprecated; use '%s' instead
      - mysql.exceptions.server.Delayed_Insert_Table_Locked: INSERT DELAYED can't be used with table '%s' because it is locked with LOCK TABLES
      - mysql.exceptions.server.Zlib_Z_Mem_Error: ZLIB: Not enough memory
      - mysql.exceptions.server.Fparser_Too_Big_File: Configuration file '%s' is too big
      - mysql.exceptions.server.Foreign_Data_String_Invalid: The data source connection string '%s' is not in the correct format
      - mysql.exceptions.server.Multiple_Pri_Key: Multiple primary key defined
      - mysql.exceptions.server.Sp_Wrong_No_Of_Fetch_Args: Incorrect number of FETCH variables
      - mysql.exceptions.server.Select_Reduced: Select %u was reduced during optimization
      - mysql.exceptions.server.Bad_Slave_Until_Cond: Incorrect parameter or combination of parameters for START SLAVE UNTIL
      - mysql.exceptions.client.Probe_Slave_Connect: Error connecting to slave:.
      - mysql.exceptions.server.Lock_Or_Active_Transaction: Can't execute the given command because you have active locked tables or an active transaction
      - mysql.exceptions.server.Too_Big_Displaywidth: Display width out of range for column '%s' (max = %d)
      - mysql.exceptions.server.Mixing_Not_Allowed: Mixing of transactional and non-transactional tables is disabled
      - mysql.exceptions.server.Sp_Wrong_No_Of_Args: Incorrect number of arguments for %s %s; expected %u, got %u
      - mysql.exceptions.server.Trg_Cant_Change_Row: Updating of %s row is not allowed in %strigger
      - mysql.exceptions.server.Wrong_Key_Column: The used storage engine can't index column '%s'
      - mysql.exceptions.server.Slave_Ignored_Table: Slave SQL thread ignored the query because of replicate-*-table rules
      - mysql.exceptions.server.Relay_Log_Init: Failed initializing relay log position: %s
      - mysql.exceptions.server.Dup_Unique: Can't write, because of unique constraint, to table '%s'
      - mysql.exceptions.client.Probe_Master_Connect: Error connecting to master:.
      - mysql.exceptions.server.Get_Errno: Got error %d from storage engine
      - mysql.exceptions.client.Fetch_Canceled: Row retrieval was canceled by mysql_stmt_close() call.
      - mysql.exceptions.server.Textfile_Not_Readable: The file '%s' must be in the database directory or be readable by all
      - mysql.exceptions.server.Sp_Wrong_Name: Incorrect routine name '%-.64s'
      - mysql.exceptions.server.Relay_Log_Fail: Failed purging old relay logs: %s
      - mysql.exceptions.server.Bad_Null_Error: Column '%s' cannot be null
      - mysql.exceptions.server.Primary_Cant_Have_Null: All parts of a PRIMARY KEY must be NOT NULL; if you need NULL in a key, use UNIQUE instead
      - mysql.exceptions.server.Tablename_Not_Allowed_Here: Table '%s' from one of the SELECTs cannot be used in %s
      - mysql.exceptions.server.Sp_Noreturn: No RETURN found in FUNCTION %s
      - mysql.exceptions.server.Stack_Overrun_Need_More: Thread stack overrun: %ld bytes used of a %ld byte stack, and %ld bytes needed.
      - mysql.exceptions.server.Unknown_Collation: Unknown collation: '%s'
      - mysql.exceptions.server.Too_Big_Precision: Too big precision %d specified for column '%s'.
      - mysql.exceptions.server.Variable_Is_Not_Struct: Variable '%s' is not a variable component (can't be used as XXXX.variable_name)
      - mysql.exceptions.server.View_No_Insert_Field_List: Can not insert into join view '%s.%s' without fields list
      - mysql.exceptions.server.Binlog_Create_Routine_Need_Super: You do not have the SUPER privilege and binary logging is enabled (you might want to use the less safe log_bin_trust_function_creators variable)
      - mysql.exceptions.server.Cant_Find_System_Rec: Can't read record in system table
      - mysql.exceptions.server.Regexp_Error: Got error '%s' from regexp
      - mysql.exceptions.server.Bad_Host_Error: Can't get hostname for your address
      - mysql.exceptions.server.Sp_Label_Mismatch: End-label %s without match
      - mysql.exceptions.server.Tableaccess_Denied_Error: %s command denied to user '%s'@'%s' for table '%s'
      - mysql.exceptions.server.Max_Prepared_Stmt_Count_Reached: Can't create more than max_prepared_stmt_count statements (current value: %lu)
      - mysql.exceptions.server.Error_When_Executing_Command: Error when executing command %s: %s
      - mysql.exceptions.server.Bad_Ft_Column: Column '%s' cannot be part of FULLTEXT index
      - mysql.exceptions.server.Too_Many_Rows: Result consisted of more than one row
      - mysql.exceptions.server.Warn_Data_Truncated: Data truncated for column '%s' at row %ld
      - mysql.exceptions.server.Unknown_Procedure: Unknown procedure '%s'
      - mysql.exceptions.server.Blob_Key_Without_Length: BLOB/TEXT column '%s' used in key specification without a key length
      - mysql.exceptions.server.Net_Read_Interrupted: Got timeout reading communication packets
      - mysql.exceptions.server.Master_Net_Write: Net error writing to master
      - mysql.exceptions.server.Sp_Bad_Sqlstate: Bad SQLSTATE: '%s'
      - mysql.exceptions.server.Cant_Aggregate_2Collations: Illegal mix of collations (%s,%s) and (%s,%s) for operation '%s'
      - mysql.exceptions.server.Ready: %s: ready for connections.
      - mysql.exceptions.server.Dup_Keyname: Duplicate key name '%s'
      - mysql.exceptions.server.Table_Not_Locked: Table '%s' was not locked with LOCK TABLES
      - mysql.exceptions.server.Net_Read_Error_From_Pipe: Got a read error from the connection pipe
      - mysql.exceptions.server.Master_Net_Read: Net error reading from master
      - mysql.exceptions.server.Trg_Already_Exists: Trigger already exists
      - mysql.exceptions.client.Wrong_Host_Info: Wrong host info.
      - mysql.exceptions.server.Cannot_User: Operation %s failed for %s
      - mysql.exceptions.server.Wrong_Sum_Select: Statement has sum functions and columns in same statement
      - mysql.exceptions.server.Read_Only_Transaction: Update locks cannot be acquired during a READ UNCOMMITTED transaction
      - mysql.exceptions.server.Bad_DB_Error: Unknown database '%s'
      - mysql.exceptions.server.Xa_Rbrollback: XA_RBROLLBACK: Transaction branch was rolled back
      - mysql.exceptions.server.Table_Needs_Upgrade: Table upgrade required.
      - mysql.exceptions.server.Too_Long_Body: Routine body for '%s' is too long
      - mysql.exceptions.server.Error_On_Read: Error reading file '%s' (errno: %d)
      - mysql.exceptions.server.Query_On_Master: Error running query on master: %s
      - mysql.exceptions.server.Wrong_Arguments: Incorrect arguments to %s
      - mysql.exceptions.server.Xaer_Dupid: XAER_DUPID: The XID already exists
      - mysql.exceptions.server.Table_Must_Have_Columns: A table must have at least 1 column
      - mysql.exceptions.server.Stack_Overrun: Thread stack overrun: Used: %ld of a %ld stack.
      - mysql.exceptions.server.Unknown_Character_Set: Unknown character set: '%s'
      - mysql.exceptions.server.Wrong_Table_Name: Incorrect table name '%s'
      - mysql.exceptions.server.Wrong_DB_Name: Incorrect database name '%s'
      - mysql.exceptions.server.Wrong_String_Length: String '%-.70s' is too long for %s (should be no longer than %d)
      - mysql.exceptions.server.Net_Packets_Out_Of_Order: Got packets out of order
      - mysql.exceptions.server.Error_During_Rollback: Got error %d during ROLLBACK
      - mysql.exceptions.server.Grant_Wrong_Host_Or_User: The host or user argument to GRANT is too long
      - mysql.exceptions.server.No_Default_For_Field: Field '%s' doesn't have a default value
      - mysql.exceptions.server.Blobs_And_No_Terminated: You can't use fixed rowlength with BLOBs; please use 'fields terminated by'
      - mysql.exceptions.server.Query_On_Foreign_Data_Source: There was a problem processing the query on the foreign data source.
      - mysql.exceptions.server.Filsort_Abort: Sort aborted
      - mysql.exceptions.server.Table_Exists_Error: Table '%s' already exists
      - mysql.exceptions.server.Sp_Goto_In_Hndlr: GOTO is not allowed in a stored procedure handler
      - mysql.exceptions.server.Cant_Aggregate_3Collations: Illegal mix of collations (%s,%s), (%s,%s), (%s,%s) for operation '%s'
      - mysql.exceptions.server.Ft_Matching_Key_Not_Found: Can't find FULLTEXT index matching the column list
      - mysql.exceptions.client.Secure_Auth: Connection using old (pre-4.1.1) authentication protocol refused (client option 'secure_auth' enabled).
      - mysql.exceptions.server.Blob_Used_As_Key: BLOB column '%s' can't be used in key specification with the used table type
      - mysql.exceptions.server.Query_Interrupted: Query execution was interrupted
      - mysql.exceptions.server.Cant_Open_File: Can't open file: '%s' (errno: %d)
      - mysql.exceptions.server.Too_Many_Keys: Too many keys specified; max %d keys allowed
      - mysql.exceptions.server.Unknown_Key_Cache: Unknown key cache '%s'
      - mysql.exceptions.server.File_Used: '%s' is locked against change
      - mysql.exceptions.server.Warn_Data_Out_Of_Range: Out of range value adjusted for column '%s' at row %ld
      - mysql.exceptions.server.Table_Def_Changed: Table definition has changed, please retry transaction
      - mysql.exceptions.server.Key_Does_Not_Exits: Key '%s' doesn't exist in table '%s'
      - mysql.exceptions.server.Net_Fcntl_Error: Got an error from fcntl()
      - mysql.exceptions.server.Sp_Cursor_Already_Open: Cursor is already open
      - mysql.exceptions.server.Row_Is_Referenced_2: Cannot delete or update a parent row: a foreign key constraint fails (%s)
      - mysql.exceptions.server.Record_File_Full: The table '%s' is full
      - mysql.exceptions.server.File_Not_Found: Can't find file: '%s' (errno: %d)
      - mysql.exceptions.server.Slave_Was_Running: Slave is already running
      - mysql.exceptions.server.Net_Error_On_Write: Got an error writing communication packets
      - mysql.exceptions.server.Sp_Badselect: PROCEDURE %s can't return a result set in the given context
      - mysql.exceptions.server.No_DB_Error: No database selected
      - mysql.exceptions.server.Wrong_Sub_Key: Incorrect sub part key; the used key part isn't a string, the used length is longer than the key part, or the storage engine doesn't support unique sub keys
      - mysql.exceptions.server.Blob_Cant_Have_Default: BLOB/TEXT column '%s' can't have a default value
      - mysql.exceptions.server.Wrong_Group_Field: Can't group on '%s'
      - mysql.exceptions.server.Wsas_Failed: WSAStartup Failed
      - mysql.exceptions.server.Crashed_On_Usage: Table '%s' is marked as crashed and should be repaired
      - mysql.exceptions.server.Error_During_Commit: Got error %d during COMMIT
      - mysql.exceptions.server.File_Exists_Error: File '%s' already exists
      - mysql.exceptions.server.Sp_Cursor_Mismatch: Undefined CURSOR: %s
      - mysql.exceptions.client.Named_Pipe_Wait_Error: Failed to wait for a named pipe on Windows.
      - mysql.exceptions.server.Cant_Delete_File: Error on delete of '%s' (errno: %d)
      - mysql.exceptions.server.No_Binary_Logging: You are not using binary logging
      - mysql.exceptions.server.Error_During_Checkpoint: Got error %d during CHECKPOINT
      - mysql.exceptions.client.Shared_Memory_Connect_File_Map_Error: Can't open shared memory; server could not allocate file mapping.
      - mysql.exceptions.server.Field_Specified_Twice: Column '%s' specified twice
      - mysql.exceptions.server.Too_Big_Fieldlength: Column length too big for column '%s' (max = %d); use BLOB or TEXT instead
      - mysql.exceptions.server.Union_Tables_In_Different_Dir: Incorrect table definition; all MERGE tables must be in the same database
      - mysql.exceptions.server.Wrong_Parameters_To_Procedure: Incorrect parameters to procedure '%s'
      - mysql.exceptions.client.Named_Pipe_Set_State_Error: Failed to get a pipe handler on Windows.
      - mysql.exceptions.server.Cant_Update_With_Readlock: Can't execute the query because you have a conflicting read lock
      - mysql.exceptions.server.Net_Packet_Too_Large: Got a packet bigger than 'max_allowed_packet' bytes
      - mysql.exceptions.server.Got_Signal: %s: Got signal %d.
      - mysql.exceptions.server.Cant_Create_User_With_Grant: You are not allowed to create a user with GRANT
      - mysql.exceptions.server.No: NO
      - mysql.exceptions.server.Binlog_Purge_Prohibited: Server configuration does not permit binlog purge
      - mysql.exceptions.server.Not_Keyfile: Incorrect key file for table '%s'; try to repair it
      - mysql.exceptions.client.Probe_Slave_Hosts: Error on SHOW SLAVE HOSTS:.
      - mysql.exceptions.client.Shared_Memory_Connect_Answer_Error: Can't open shared memory; no answer event received from server.
      - mysql.exceptions.server.Warn_View_Merge: View merge algorithm can't be used here for now (assumed undefined algorithm)
      - mysql.exceptions.server.Sp_Fetch_No_Data: No data to FETCH
      - mysql.exceptions.server.Xaer_Outside: XAER_OUTSIDE: Some work is done outside global transaction
      - mysql.exceptions.server.Cant_Create_Thread: Can't create a new thread (errno %d); if you are not out of available memory, you can consult the manual for a possible OS-dependent bug
      - mysql.exceptions.server.Nisamchk: isamchk
      - mysql.exceptions.server.Table_Cant_Handle_Spkeys: The used table type doesn't support SPATIAL indexes
      - mysql.exceptions.server.Too_Many_Key_Parts: Too many key parts specified; max %d parts allowed
      - mysql.exceptions.server.Wrong_Column_Name: Incorrect column name '%s'
      - mysql.exceptions.server.Stmt_Not_Allowed_In_Sf_Or_Trg: %s is not allowed in stored function or trigger
      - mysql.exceptions.client.Shared_Memory_Connect_Abandoned_Error: Can't open shared memory; no answer from server.
      - mysql.exceptions.server.Feature_Disabled: The '%s' feature is disabled; you need MySQL built with '%s' to have it working
      - mysql.exceptions.server.Binlog_Unsafe_Routine: This function has none of DETERMINISTIC, NO SQL, or READS SQL DATA in its declaration and binary logging is enabled (you might want to use the less safe log_bin_trust_function_creators variable)
      - mysql.exceptions.server.Duplicated_Value_In_Type: Column '%s' has duplicated value '%s' in %s
      - mysql.exceptions.server.Row_Is_Referenced: Cannot delete or update a parent row: a foreign key constraint fails
      - mysql.exceptions.server.Sp_Cursor_After_Handler: Cursor declaration after handler declaration
      - mysql.exceptions.server.Cant_Create_Table: Can't create table '%s' (errno: %d)
      - mysql.exceptions.server.Reserved_Syntax: The '%s' syntax is reserved for purposes internal to the MySQL server
      - mysql.exceptions.server.View_Select_Tmptable: View's SELECT refers to a temporary table '%s'
      - mysql.exceptions.server.Fparser_Eof_In_Unknown_Parameter: Unexpected end of file while skipping unknown parameter '%s'
      - mysql.exceptions.server.Warn_Too_Many_Records: Row %ld was truncated; it contained more data than there were input columns
      - mysql.exceptions.server.Wrong_Field_Terminators: Field separator argument is not what is expected; check the manual
      - mysql.exceptions.server.Warn_Cant_Drop_Default_Keycache: Cannot drop default keycache
    - mysql.exceptions.internal.Connected_Error: Attempted to use a command that cannot be used while connected.
    - mysql.exceptions.internal.Statement_Closed_Error: Attempted to use a statement object that has been closed.
    - mysql.exceptions.internal.Not_Connected_Error: Tried to run a command when no connection is established.
    - mysql.exceptions.internal.Data_Truncated: Data was truncated in the last fetch.
    - mysql.exceptions.internal.No_More_Results: No more results are available in the mysql.connection.Connection.next_result method.
    - mysql.exceptions.internal.Affected_Rows_Unavailable: The number of affected rows is not available.
    - mysql.exceptions.internal.No_Insert_ID_Error: The last insert ID is not available when calling the mysql.connection.Connection.last_insert_id method.
- mysql.connection.Character_Set: Information about a character set.
- mysql.conversion.input.Input_Conversion: Base class for the input conversion API.
  - mysql.conversion.input.Basic_Conversion: The default conversion class used if none is specified.
- mysql.conversion.output.Output_Conversion: Base class for the output conversion API.
  - mysql.conversion.output.No_Conversion: Does no conversion, all values are returned as strings.
  - mysql.conversion.output.Basic_Conversion: The default conversion class used if none is specified.
- mysql.result.Field: The description of a column in a SELECT query.
- object: The most base type
  - mysql.result.Result: Query result object.
  - mysql.connection._Statement_Cleaner: Statement cleaning object.
  - mysql.stmt.bind_out.Output_Bind: Base output binding class.
    - mysql.stmt.bind_out.Out_Timestamp: TIMESTAMP output binding.
    - mysql.stmt.bind_out.Out_Bit: BIT output binding.
    - mysql.stmt.bind_out.Out_Year: YEAR output binding.
    - mysql.stmt.bind_out.Out_U_Big_Int: UNSIGNED BIGINT output binding.
    - mysql.stmt.bind_out.Out_U_Int: UNSIGNED INT output binding.
    - mysql.stmt.bind_out.Out_Null: Null output binding.
    - mysql.stmt.bind_out.Base_Out_Stream: Base class for streaming output.
      - mysql.stmt.bind_out.Out_Long_Blob: LONGBLOB output binding.
      - mysql.stmt.bind_out.Out_Tiny_Blob: TINYBLOB output binding.
      - mysql.stmt.bind_out.Out_Blob: BLOB output binding.
      - mysql.stmt.bind_out.Out_Medium_Blob: MEDIUMBLOB output binding.
    - mysql.stmt.bind_out.Out_U_Tiny_Int: UNSIGNED TINYINT output binding.
    - mysql.stmt.bind_out.Out_Big_Int: BIGINT output binding.
    - mysql.stmt.bind_out.Out_Int: INT output binding.
    - mysql.stmt.bind_out.Out_Date: DATE output binding.
    - mysql.stmt.bind_out.Out_Date_Time: DATETIME output binding.
    - mysql.stmt.bind_out.Out_Tiny_Int: TINYINT output binding.
      - mysql.stmt.bind_out.Out_Bool: BOOL output binding.
    - mysql.stmt.bind_out.Out_Decimal: DECIMAL output binding.
      - mysql.stmt.bind_out.Out_New_Decimal: NEW DECIMAL output binding.
    - mysql.stmt.bind_out.Out_Small_Int: SMALLINT output binding.
    - mysql.stmt.bind_out.Out_Float: FLOAT output binding.
    - mysql.stmt.bind_out.Out_Double: DOUBLE output binding.
    - mysql.stmt.bind_out.Out_Time: TIME output binding.
    - mysql.stmt.bind_out.Base_Out_String: Base string-type output binding.
      - mysql.stmt.bind_out.Out_Varchar: VARCHAR output binding.
      - mysql.stmt.bind_out.Out_Set: SET output binding.
      - mysql.stmt.bind_out.Out_Char: CHAR output binding.
    - mysql.stmt.bind_out.Out_U_Small_Int: UNSIGNED SMALLINT output binding.
  - mysql.connection.Connection: MySQL connection object.
  - mysql.stmt.bind_in.Input_Stream: Input Stream.
  - mysql.stmt.stmt.Statement: Parsed SQL statement object.
  - mysql.stmt.bind_in.Input_Bind: Base input binding class.
    - mysql.stmt.bind_in.Base_In_Stream: Base class for streaming input.
      - mysql.stmt.bind_in.In_Long_Blob: LONGBLOB input binding.
      - mysql.stmt.bind_in.In_Tiny_Blob: TINYBLOB input binding.
      - mysql.stmt.bind_in.In_Medium_Blob: MEDIUMBLOB input binding.
      - mysql.stmt.bind_in.In_Blob: BLOB input binding.
    - mysql.stmt.bind_in.In_Time: TIME input binding.
    - mysql.stmt.bind_in.In_Float: FLOAT input binding.
    - mysql.stmt.bind_in.In_U_Double: UNSIGNED DOUBLE input binding.
    - mysql.stmt.bind_in.In_U_Small_Int: UNSIGNED SMALLINT input binding.
    - mysql.stmt.bind_in.In_Year: YEAR input binding.
    - mysql.stmt.bind_in.In_Tiny_Int: TINYINT input binding.
      - mysql.stmt.bind_in.In_Bool: BOOL input binding.
    - mysql.stmt.bind_in.In_U_Tiny_Int: UNSIGNED TINYINT input binding.
    - mysql.stmt.bind_in.In_U_Int: UNSIGNED INT input binding.
    - mysql.stmt.bind_in.In_Big_Int: BIGINT input binding.
    - mysql.stmt.bind_in.In_Int: INT input binding.
    - mysql.stmt.bind_in.In_Small_Int: SMALLINT input binding.
    - mysql.stmt.bind_in.In_Null: Null input binding.
    - mysql.stmt.bind_in.Base_Decimal: Signed Decimal input binding.
      - mysql.stmt.bind_in.In_New_Decimal: Signed "new" decimal input binding.
      - mysql.stmt.bind_in.In_U_New_Decimal: Unsigned "new" decimal input binding.
      - mysql.stmt.bind_in.In_Decimal: Signed Decimal input binding.
      - mysql.stmt.bind_in.In_U_Decimal: Unsigned Decimal input binding.
    - mysql.stmt.bind_in.In_U_Medium_Int: UNSIGNED MEDIUMINT input binding.
    - mysql.stmt.bind_in.Base_In_String: Base class input binding that is a character array from a string.
      - mysql.stmt.bind_in.In_Varchar: VARCHAR input binding.
        - mysql.stmt.bind_in.In_Set: SET input binding.
        - mysql.stmt.bind_in.In_Enum: ENUM input binding.
      - mysql.stmt.bind_in.In_Char: CHAR input binding.
    - mysql.stmt.bind_in.In_Double: DOUBLE input binding.
    - mysql.stmt.bind_in.In_Date: DATE input binding.
    - mysql.stmt.bind_in.In_Date_Time: DATETIME input binding.
    - mysql.stmt.bind_in.In_Timestamp: TIMESTAMP input binding.
    - mysql.stmt.bind_in.In_Medium_Int: MEDIUMINT input binding.
    - mysql.stmt.bind_in.In_Bit: BIT input binding.
    - mysql.stmt.bind_in.In_U_Float: UNSIGNED FLOAT input binding.
    - mysql.stmt.bind_in.In_U_Big_Int: UNSIGNED BIG INT input binding.
  - mysql.result.Row_Offset: Representation of a result offset.
  - mysql.stmt.bind_out.Output_Stream: Output stream.